#
# spec file for package perl-Date-Calc
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Date-Calc
BuildRequires:  perl(Bit::Vector) >= 7.1
BuildRequires:  perl(Carp::Clan) >= 6.04
Requires:       perl(Bit::Vector) >= 7.1
Requires:       perl(Carp::Clan) >= 6.04
BuildRequires:  perl-macros
Version:        6.3
Release:        27.3
Provides:       DateCalc
Provides:       perl_dc
Obsoletes:      perl_dc
Url:            http://search.cpan.org/perldoc?Date::Calc
Summary:        Perl Date-Calc Module
License:        Artistic-1.0 or GPL-2.0+
Group:          Development/Libraries/Perl
Source:         http://search.cpan.org/CPAN/authors/id/S/ST/STBEY/Date-Calc-%{version}.tar.gz
Patch:          Date-Calc-%{version}.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{perl_requires}

%description
This package consists of a C library and a Perl module (which uses the
C library, internally) for all kinds of date calculations based on the
Gregorian calendar (the one used in all western countries today),
thereby complying with all relevant norms and standards: ISO/R
2015-1971, DIN 1355 and, to some extent, ISO 8601 (where applicable).

(See also http://www.engelschall.com/u/sb/download/Date-Calc/DIN1355/
for a scan of part of the "DIN 1355" document (in German)).

The module of course handles year numbers of 2000 and above correctly
("Year 2000" or "Y2K" compliance) -- actually all year numbers from 1
to the largest positive integer representable on your system (which is
at least 32767) can be dealt with.

Note that this package EXTRAPOLATES the Gregorian calendar BACK until
the year 1 A.D. -- even though the Gregorian calendar was only adopted
in 1582 by most (not all) European countries, in obedience to the
corresponding decree of catholic pope Gregor I in that year.

Some (mainly protestant) countries continued to use the Julian calendar
(used until then) until as late as the beginning of the 20th century.

Finally, note that this package is not intended to do everything you
could ever imagine automagically for you; it is rather intended to
serve as a toolbox (in the best of UNIX spirit and traditions) which
should, however, always get you where you want to go.

%prep
%setup -n Date-Calc-%{version} -q
%patch -p1

%build
perl Makefile.PL OPTIMIZE="$RPM_OPT_FLAGS -Wall"
make %{?_smp_mflags}

%check
make test

%install
make DESTDIR=$RPM_BUILD_ROOT install_vendor
%perl_process_packlist
chmod -R u+w *.txt
for i in `ls *.txt`; do mv $i `basename $i .txt`; done
rm -rf tools/compile.bat
rm -rf $RPM_BUILD_ROOT%{_mandir}/man3/Carp::*
rm -rf $RPM_BUILD_ROOT%{perl_vendorarch}/Carp

%clean
rm -rf $RPM_BUILD_ROOT

%files 
%defattr(-, root, root)
%doc license README CREDITS CHANGES MANIFEST 
%doc %{_mandir}/man?/*
%{perl_vendorarch}/auto/Date/
%{perl_vendorlib}/Date/

%changelog
* Sun Jan  4 2015 coolo@suse.com
- Date::Calc's parse logic puts 3.1.64 into 2064 if it's closer to
  $NOW than 1964, which is the case since 1.1.2015
  updated Date-Calc-6.3.diff for
  https://rt.cpan.org/Public/Bug/Display.html?id=101232
- SP1 backport: bsc#931431
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Feb 27 2013 coolo@suse.com
- update license to new format
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Fri Feb 26 2010 anicka@suse.cz
- update to 6.3
  * The language can now be set individually for each function
    in "Date::Calc" that requires it (through a new optional
    parameter; the default continues to be a global setting
    for backward compatibility); the affected functions are:
    "Decode_Month()", "Decode_Day_of_Week()", "Compressed_to_Text()",
    "Date_to_Text()", "Date_to_Text_Long()", "Calendar()",
    "Month_to_Text()", "Day_of_Week_to_Text()", "Day_of_Week_Abbreviation()",
    "Decode_Date_EU()", "Decode_Date_US()", "Decode_Date_EU2()",
    "Decode_Date_US2()", "Parse_Date()".
  * BEWARE that the interface of "DateCalc.c" has changed!
  * Module "Date::Calc::Object" has been changed similarly
  * Module "Date::Calendar::Year" has also been adapted accordingly
  * bugfixes
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 5.6
  * Made the module MacOS X compatible
  * Made some tiny changes to the documentation
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 cthiel@suse.de
- added perl-Carp-Clan to neededforbuild
* Mon Aug  1 2005 cthiel@suse.de
- update to version 5.4
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Mon May 26 2003 mjancar@suse.cz
- remove Carp::Clan conflicting with perl-Bit-Vector
* Thu May 22 2003 mjancar@suse.cz
- use $RPM_OPT_FLAGS
- use #!/usr/bin/perl instead of #!perl in examples
- package omited man page
- dont package MANIFEST
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Thu Dec 19 2002 prehak@suse.cz
- updated to version 5.3
- added doc files, adjusted their permissions
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Tue Jan 22 2002 rvasice@suse.cz
- update to version 5.0
- actualize filelist
- use macros %%{perl_sitearch}, %%{perl_archlib}, %%{_prefix}
- added make test
* Mon Nov  6 2000 grimmer@suse.de
- renamed from perl_dc to perl-Date-Calc
- update to Version 4.3
- spec file cleanups (macros, BuildRoot)
* Fri Jan 21 2000 ro@suse.de
- fixed filelist
* Thu Oct 28 1999 tmg@suse.de
- created package (Date-Calc-4.2)
